@@ -108,7 +108,7 @@ class MyDenseNet(nn.Module):
 
 class Antigens():
     def __init__(self, fasta_file, esm1b_encoding_dir,
-        add_seq_len=False, run_esm_model_local=False):
+        add_seq_len=False, run_esm_model_local=None):
         """
         Initialize Antigens class object
         Inputs:
@@ -154,8 +154,11 @@ class Antigens():
         fastaPath = self.esm1b_encoding_dir / "antigens.fasta"
         
         try: #only using this for biolib implementation 
-            if self.run_esm_model_local:
-                subprocess.check_call(['python', ESM_LOCAL_SCRIPT_PATH, "local", fastaPath, self.esm1b_encoding_dir, "--include", "per_tok", "--truncate"])
+            if self.run_esm_model_local is not None:
+                if self.run_esm_model_local.is_file():
+                    subprocess.check_call(['python', ESM_LOCAL_SCRIPT_PATH, self.run_esm_model_local, fastaPath, self.esm1b_encoding_dir, "--include", "per_tok", "--truncate"])
+                else:
+                    sys.exit(f"Could not find local model: {self.run_esm_model_local}.")
             else:
                 subprocess.check_call(['python', ESM_SCRIPT_PATH, "esm1b_t33_650M_UR50S", fastaPath, self.esm1b_encoding_dir, "--include", "per_tok", "--truncate"])
         except subprocess.CalledProcessError as error:
